import React, {useRef, useState} from 'react';
import './index.scss';
import PopoverContent from "./PopoverContent";

interface PopoverProps {
  width: number;
  content: React.ReactNode | string;
}

const Popover: React.FunctionComponent<PopoverProps> = (props) => {
  const [isVisible, setVisible] = useState(false);
  const [position, setPosition] = useState({top: 0, left: 0});

  const triggerRef = useRef(null);

  function open() {
    if (triggerRef) {
      const trigger = triggerRef.current as unknown as HTMLElement;
      let {left, top} = trigger.getBoundingClientRect();
      setPosition({top, left});
      setVisible(true);
    }
  }

  function close() {
    setVisible(false)
  }

  return (
   <div className="w-popover">
     <PopoverContent top={position.top} left={position.left} width={props.width} isVisible={isVisible} content={props.content}/>
     <div className="w-trigger" onMouseEnter={open}  ref={triggerRef} onMouseLeave={close} >
       <div className="text-ellipsis" style={{width: `${props.width}px`}}>
         {props.children}
       </div>
     </div>
   </div>
  );
};

export default Popover;
