import * as React from "react";
import {useEffect, useRef, useState} from "react";
import ReactDOM from "react-dom";
import './index.scss';

interface PopoverContentProps {
  top: number;
  left: number;
  width: number;
  isVisible: boolean;
  content: React.ReactNode | string;
}

type Position = 'top' | 'bottom';

const PopoverContent: React.FunctionComponent<PopoverContentProps> = (props) => {
  const [contentClass, setClass] = useState('w-content w-position-top');
  const [isInContent, setIsInContent] = useState(false);
  const contentRef = useRef(null);
  const { isVisible, width, left, top } = props;

  useEffect(()=> {
    function positionContent(position: Position) {
      let positions = {
        top: {
          left: left + window.scrollX + width / 2 + 'px',
          top: top + window.scrollY + 'px'
        },
        bottom: {
          left: left + window.scrollX + width / 2 + 'px',
          top: top + window.scrollY + 'px'
        },
      };

      const content = contentRef.current as unknown as HTMLElement;
      content.style.left = positions[position].left;
      content.style.top = positions[position].top;
    }

    if (isVisible || isInContent) {
      console.log(top + window.screenY);
      if (top + window.scrollY > 60) {
        positionContent('top');
        setClass('w-content w-position-top w-content-visible');
      } else {
        positionContent('bottom');
        setClass('w-content w-position-bottom w-content-visible');
      }
    } else {
      setClass('w-content');
    }
  }, [left, top, width, isVisible, isInContent]);

  function open() {
    setIsInContent(true)
  }

  function close() {
    setIsInContent(false);
  }

  const renderContent =  (
    <div className={contentClass} ref={contentRef} onMouseEnter={open} onMouseLeave={close}>
      {props.content}
      <div className="w-mask"></div>
    </div>
  );

  return ReactDOM.createPortal(renderContent, document.body);
};

export default PopoverContent;
